### Name: gpcm-methods
### Title: Partial Credit/Generalized Partial Credit Model Response
###   Probabilities
### Aliases: gpcm gpcm-methods gpcm,matrix,numeric-method
###   gpcm,data.frame,numeric-method gpcm,list,numeric-method
###   gpcm,irt.pars,ANY-method gpcm,sep.pars,ANY-method
### Keywords: methods distribution

### ** Examples

## Partial Credit Model
## Item parameters from Embretson & Reise (2000, p. 108) item 5
b <- t(c(-2.519,-.063,.17,2.055))
x <- gpcm(b,5)
plot(x) 

## Generalized Partial Credit Model
## Item parameters from Embretson & Reise (2000, p. 112) items 5-7
a <- c(.683,1.073,.583)
b <- matrix(c(-3.513,-.041,.182,NA,-.873,.358,-.226,1.547,-4.493,-.004,NA,NA),3,4,byrow=TRUE)
pars <- cbind(a,b) # Does not include a location parameter
rownames(pars) <- paste("Item",5:7,sep="") 
colnames(pars) <- c("a",paste("b",1:4,sep=""))
cat <- c(4,5,3)
x <- gpcm(pars,cat,seq(-3,3,.05))
plot(x)

## Item parameters from Muraki (1992, p. 154)
a <- c(1,.5)
b <- matrix(c(.25,-1.75,1.75,.75,-1.25,1.25),2,3,byrow=TRUE)
pars <- cbind(a,b) # Include a location parameter
rownames(pars) <- paste("Item",1:2,sep="")
colnames(pars) <- c("a","b",paste("d",1:2,sep=""))
cat <- c(3,3)
x <- gpcm(pars,cat,location=TRUE,print.mod=TRUE)
# Plot category curves for two items
matplot(seq(-4,4,.05),x@prob[,2:4],xlab="Theta",ylab="Probability",ylim=c(0,1),lty=1,
  type="l",col="black") 
par(new=TRUE)
matplot(seq(-4,4,.05),x@prob[,5:7],xlab="Theta",ylab="Probability",ylim=c(0,1),lty=3,
  type="l",col="black") 



